@@ -32,7 +32,7 @@ logger = logging.getLogger(__name__)
 
 
 def get_files(search_path=False, **kwargs):
-    file.get_files(search_path, **kwargs)
+    return file.get_files(search_path, **kwargs)
 
 
 def create(path, dir_name=False, **kwargs):
